==> kibana-6.6.1.tgz: kibana/src/legacy/core_plugins/kibana/public/management/sections/objects/index.js <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { i18n } from '@kbn/i18n';
import { management } from 'ui/management';
import './_view';
import './_objects';
import 'ace';
import 'ui/directives/confirm_click';
import { uiModules } from 'ui/modules';
import { FeatureCatalogueRegistryProvider, FeatureCatalogueCategory } from 'ui/registry/feature_catalogue';

// add the module deps to this module
uiModules.get('apps/management');

management.getSection('kibana').register('objects', {
  display: i18n.translate('kbn.management.objects.savedObjectsSectionLabel', {
    defaultMessage: 'Saved Objects',
  }),
  order: 10,
  url: '#/management/kibana/objects'
});

FeatureCatalogueRegistryProvider.register(() => {
  return {
    id: 'saved_objects',
    title: i18n.translate('kbn.management.objects.savedObjectsTitle', {
      defaultMessage: 'Saved Objects',
    }),
    description: i18n.translate('kbn.management.objects.savedObjectsDescription', {
      defaultMessage: 'Import, export, and manage your saved searches, visualizations, and dashboards.',
    }),
    icon: 'savedObjectsApp',
    path: '/app/kibana#/management/kibana/objects',
    showOnHomePage: true,
    category: FeatureCatalogueCategory.ADMIN
  };
});

==> kibana-7.6.2p0.tgz: kibana/src/legacy/core_plugins/kibana/public/management/sections/objects/index.js <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { i18n } from '@kbn/i18n';
import { management } from 'ui/management';
import './_view';
import './_objects';
import 'ace';
import { uiModules } from 'ui/modules';
import {
  FeatureCatalogueRegistryProvider,
  FeatureCatalogueCategory,
} from 'ui/registry/feature_catalogue';

// add the module deps to this module
uiModules.get('apps/management');

management.getSection('kibana').register('objects', {
  display: i18n.translate('kbn.management.objects.savedObjectsSectionLabel', {
    defaultMessage: 'Saved Objects',
  }),
  order: 10,
  url: '#/management/kibana/objects',
});

FeatureCatalogueRegistryProvider.register(() => {
  return {
    id: 'saved_objects',
    title: i18n.translate('kbn.management.objects.savedObjectsTitle', {
      defaultMessage: 'Saved Objects',
    }),
    description: i18n.translate('kbn.management.objects.savedObjectsDescription', {
      defaultMessage:
        'Import, export, and manage your saved searches, visualizations, and dashboards.',
    }),
    icon: 'savedObjectsApp',
    path: '/app/kibana#/management/kibana/objects',
    showOnHomePage: true,
    category: FeatureCatalogueCategory.ADMIN,
  };
});
